@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.008001;
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 sub true () {
     require Data::MessagePack::Boolean;
@@ -274,7 +274,7 @@ hanekomu
 
 Kazuho Oku
 
-shohex
+syohex
 
 =head1 LICENSE
 
